package org.jeecg.modules.api.service;

import io.swagger.annotations.ApiOperation;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.api.bean.PageBean;
import org.jeecg.modules.citiyShopAuthentication.entity.CitiyShopAuthentication;
import org.jeecg.modules.citiyUserAuthentication.entity.CitiyUserAuthentication;
import org.jeecg.modules.cityTrends.entity.CityTrends;
import org.springframework.web.bind.annotation.RequestMapping;

public interface YaoDuApiService {

    //获取城市列表服务区域
    Result<?> getCityList();

    //获取banner列表
    Result<?> getBannerList();


    //获取首页头部信息
    Result<?> getIndexHeaderInfo();


    //获取分类类型列表
    Result<?> getClassifyList();


    //获取分类
    Result<?> getClassInfo();


    //根据分类获取动态帖子列表带分页
    Result<?> getPostPage(PageBean pageBean);


    //根据帖子标识获取帖子详情
    Result<?> getPostDetail(String id);


    //根据分类获取租房信息列表带分页带搜
    Result<?> getRentPage(PageBean pageBean);


    //根据租房标识获取租房详情
    Result<?> getRentDetail(String id);


    //根据分类获取工作信息列表带分页带搜索
    Result<?> getJobPage(PageBean pageBean);

    //根据工作标识获取工作详情
    Result<?> getJobDetail(String id);


    //根据分类获取门店信息列表带分页带搜索
    Result<?> getStorePage(PageBean pageBean);

    //根据门店标识获取门店详情
    Result<?> getStoreDetail(String id);


    //获取活动列表信息带分页带搜索
    Result<?> getActivityPage(PageBean pageBean);


    //根据活动标识获取活动详情
    Result<?> getActivityDetail(String id);


    //获取评论信息列表
    Result<?> getCommentPage(PageBean pageBean);



    //点击查看联系方式 类型 0帖子 1租房 2工作 3门店
    Result<?> checkGivePhone(String token,String type, String id);

    //点击查看地图  类型 0帖子 1租房 2工作 3门店
    Result<?> checkMap(String token,String type, String id);

    //申请职位
    Result<?> applyJob(String token,String jobId,String name,String phone);

    //发布帖子
    Result<?> publishPost(String token, CityTrends cityTrends);

    //评论
    Result<?> comment(String token,String postId,String content);

    //个人认证
    Result<?> personalAuthentication(String token, CitiyUserAuthentication object);

    //企业认证
    Result<?> companyAuthentication(String token, CitiyShopAuthentication object);





}
